## Contributing
>Collaborators can be added on a case by case basis so please reach out if you would like to \
>contribute. As this is a personal hobby I will review any PRs and manage access and deployment \
>myself. I welcome any issues and feature requests to be submitted and will try to reply in a \
>timely manner. Please make sure to update tests as appropriate. I advise using use pre-commit to \
>help with automated testing and adhering to pylint and black formatting standards.
